@@ -1,10 +1,15 @@
 from .compute_log_manager import S3ComputeLogManager
 from .file_cache import S3FileCache, s3_file_cache
 from .file_manager import S3FileHandle, S3FileManager
-from .intermediate_store import S3IntermediateStore
+from .intermediate_storage import S3IntermediateStorage
 from .object_store import S3ObjectStore
-from .resources import s3_resource
+from .resources import s3_file_manager, s3_resource
 from .s3_fake_resource import S3FakeSession, create_s3_fake_resource
 from .solids import S3Coordinate, file_handle_to_s3
-from .system_storage import s3_plus_default_storage_defs, s3_system_storage
+from .system_storage import (
+    s3_intermediate_storage,
+    s3_plus_default_intermediate_storage_defs,
+    s3_plus_default_storage_defs,
+    s3_system_storage,
+)
 from .utils import S3Callback
